@@ -69,6 +69,7 @@ int master_alpha = 1;
 int thumb_alpha = 1;
 int list_encoders = 0;
 int two_colr_boxes = 0;
+int premultiplied_alpha = 0;
 const char* encoderId = nullptr;
 
 int nclx_matrix_coefficients = 6;
@@ -92,7 +93,7 @@ static struct option long_options[] = {
     {(char* const) "no-alpha",                no_argument,       &master_alpha,  0},
     {(char* const) "no-thumb-alpha",          no_argument,       &thumb_alpha,   0},
     {(char* const) "list-encoders",           no_argument,       &list_encoders, 1},
-    {(char* const) "encoders",                no_argument,       0,              'e'},
+    {(char* const) "encoder",                 no_argument,       0,              'e'},
     {(char* const) "bit-depth",               required_argument, 0,              'b'},
     {(char* const) "even-size",               no_argument,       0,              'E'},
     {(char* const) "avif",                    no_argument,       0,              'A'},
@@ -101,6 +102,7 @@ static struct option long_options[] = {
     {(char* const) "transfer_characteristic", required_argument, 0,              OPTION_NCLX_TRANSFER_CHARACTERISTIC},
     {(char* const) "full_range_flag",         required_argument, 0,              OPTION_NCLX_FULL_RANGE_FLAG},
     {(char* const) "enable-two-colr-boxes",   no_argument,       &two_colr_boxes, 1},
+    {(char* const) "premultiplied-alpha",     no_argument,       &premultiplied_alpha, 1},
     {0, 0,                                                       0,              0}
 };
 
@@ -118,32 +120,32 @@ void show_help(const char* argv0)
             << "Note that there is no checking for valid parameters when using the prefix.\n"
             << "\n"
             << "Options:\n"
-            << "  -h, --help       show help\n"
-            << "  -q, --quality    set output quality (0-100) for lossy compression\n"
-            << "  -L, --lossless   generate lossless output (-q has no effect)\n"
-            << "  -t, --thumb #    generate thumbnail with maximum size # (default: off)\n"
-            << "      --no-alpha   do not save alpha channel\n"
+            << "  -h, --help        show help\n"
+            << "  -q, --quality     set output quality (0-100) for lossy compression\n"
+            << "  -L, --lossless    generate lossless output (-q has no effect)\n"
+            << "  -t, --thumb #     generate thumbnail with maximum size # (default: off)\n"
+            << "      --no-alpha    do not save alpha channel\n"
             << "      --no-thumb-alpha  do not save alpha channel in thumbnail image\n"
-            << "  -o, --output     output filename (optional)\n"
-            << "  -v, --verbose    enable logging output (more -v will increase logging level)\n"
-            << "  -P, --params     show all encoder parameters\n"
-            << "  -b #             bit-depth of generated HEIF/AVIF file when using 16-bit PNG input (default: 10 bit)\n"
-            << "  -p               set encoder parameter (NAME=VALUE)\n"
-            << "  -A, --avif       encode as AVIF\n"
-            << "  --list-encoders  list all available encoders for the selected output format\n"
-            << "  -e, --encoder ID select encoder to use (the IDs can be listed with --list-encoders)\n"
-            << "  -E, --even-size  [deprecated] crop images to even width and height (odd sizes are not decoded correctly by some software)\n"
+            << "  -o, --output      output filename (optional)\n"
+            << "  -v, --verbose     enable logging output (more -v will increase logging level)\n"
+            << "  -P, --params      show all encoder parameters\n"
+            << "  -b, --bit-depth # bit-depth of generated HEIF/AVIF file when using 16-bit PNG input (default: 10 bit)\n"
+            << "  -p                set encoder parameter (NAME=VALUE)\n"
+            << "  -A, --avif        encode as AVIF\n"
+            << "      --list-encoders   list all available encoders for the selected output format\n"
+            << "  -e, --encoder     ID select encoder to use (the IDs can be listed with --list-encoders)\n"
+            << "  -E, --even-size   [deprecated] crop images to even width and height (odd sizes are not decoded correctly by some software)\n"
             << "  --matrix_coefficients     nclx profile: color conversion matrix coefficients, default=6 (see h.273)\n"
             << "  --colour_primaries        nclx profile: color primaries (see h.273)\n"
             << "  --transfer_characteristic nclx profile: transfer characteristics (see h.273)\n"
             << "  --full_range_flag         nclx profile: full range flag, default: 1\n"
             << "  --enable-two-colr-boxes   will write both an ICC and an nclx color profile if both a present\n"
+            << "  --premultiplied-alpha     input image has premultiplied alpha\n"
             << "\n"
             << "Note: to get lossless encoding, you need this set of options:\n"
             << "  -L                       switch encoder to lossless mode\n"
             << "  -p chroma=444            switch off color subsampling\n"
             << "  --matrix_coefficients=0  encode in RGB color-space\n";
-
 }
 
 
@@ -1248,6 +1250,10 @@ int main(int argc, char** argv)
       }
     }
 
+    if (premultiplied_alpha) {
+      heif_image_set_premultiplied_alpha(image.get(), premultiplied_alpha);
+    }
+
 
     struct heif_image_handle* handle;
     error = heif_context_encode_image(context.get(),
