@@ -116,7 +116,7 @@ static gboolean stop_load(gpointer context, GError** error)
     (*hpc->size_func)(&requested_width, &requested_height, hpc->user_data);
   }
 
-  if (requested_width > 0 && requested_height > 0) {
+  if (requested_width > 0 && requested_height > 0 && (width != requested_width || height != requested_height)) {
     struct heif_image* resized;
     heif_image_scale_image(img, &resized, requested_width, requested_height, NULL);
     heif_image_release(img);
