@@ -22,8 +22,10 @@
 
 #include "box.h"
 #include "bitstream.h"
+#include "logging.h"
 
-extern "C" int LLVMFuzzerTestOneInput(const uint8_t* data, size_t size) {
+extern "C" int LLVMFuzzerTestOneInput(const uint8_t* data, size_t size)
+{
   auto reader = std::make_shared<heif::StreamReader_memory>(data, size, false);
 
   heif::BitstreamRange range(reader, size);
@@ -33,6 +35,11 @@ extern "C" int LLVMFuzzerTestOneInput(const uint8_t* data, size_t size) {
     if (error != heif::Error::Ok || range.error()) {
       break;
     }
+
+    box->get_type();
+    box->get_type_string();
+    heif::Indent indent;
+    box->dump(indent);
   }
 
   return 0;
