@@ -69,40 +69,44 @@ HeifImage.prototype.display = function(image_data, callback) {
         var vval;
         var xpos = 0;
         var ypos = 0;
-        var w2 = w >> 1;
-        var maxi = w2*h;
         var yoffset = 0;
         var uoffset = 0;
         var voffset = 0;
         var x2;
-        var i2;
-        var y = this.data;
-        var u = this.data.subarray(w * h, w * h + (w * h / 4));
-        var v = this.data.subarray(w * h + (w * h / 4), w * h + (w * h / 2));
+        var i = 0;
+        var maxi = w*h;
         var stridey = w;
-        var strideu = w / 2;
-        var stridev = w / 2;
+        var strideu = Math.ceil(w / 2);
+        var stridev = Math.ceil(w / 2);
+        var h2 = Math.ceil(h / 2);
+        var y = this.data;
+        var u = this.data.subarray(stridey * h, stridey * h + (strideu * h2));
+        var v = this.data.subarray(stridey * h + (strideu * h2), stridey * h + (strideu * h2) + (stridev * h2));
         var dest = image_data.data;
-        for (var i=0; i<maxi; i++) {
-            i2 = i << 1;
-            x2 = (xpos << 1);
-            yval = 1.164 * (y[yoffset + x2] - 16);
-
-            uval = u[uoffset + xpos] - 128;
-            vval = v[voffset + xpos] - 128;
-            dest[(i2<<2)+0] = yval + 1.596 * vval;
-            dest[(i2<<2)+1] = yval - 0.813 * vval - 0.391 * uval;
-            dest[(i2<<2)+2] = yval + 2.018 * uval;
-            dest[(i2<<2)+3] = 0xff;
-
-            yval = 1.164 * (y[yoffset + x2 + 1] - 16);
-            dest[((i2+1)<<2)+0] = yval + 1.596 * vval;
-            dest[((i2+1)<<2)+1] = yval - 0.813 * vval - 0.391 * uval;
-            dest[((i2+1)<<2)+2] = yval + 2.018 * uval;
-            dest[((i2+1)<<2)+3] = 0xff;
+        while (i < maxi) {
+            x2 = (xpos >> 1);
+            yval = 1.164 * (y[yoffset + xpos] - 16);
 
+            uval = u[uoffset + x2] - 128;
+            vval = v[voffset + x2] - 128;
+            dest[(i<<2)+0] = yval + 1.596 * vval;
+            dest[(i<<2)+1] = yval - 0.813 * vval - 0.391 * uval;
+            dest[(i<<2)+2] = yval + 2.018 * uval;
+            dest[(i<<2)+3] = 0xff;
+            i++;
             xpos++;
-            if (xpos === w2) {
+
+            if (xpos < w) {
+                yval = 1.164 * (y[yoffset + xpos] - 16);
+                dest[(i<<2)+0] = yval + 1.596 * vval;
+                dest[(i<<2)+1] = yval - 0.813 * vval - 0.391 * uval;
+                dest[(i<<2)+2] = yval + 2.018 * uval;
+                dest[(i<<2)+3] = 0xff;
+                i++;
+                xpos++;
+            }
+
+            if (xpos === w) {
                 xpos = 0;
                 ypos++;
                 yoffset += stridey;
